pygeodesy.heights.HeightSmoothBiSpline

Package pygeodesy :: Module heights :: Class HeightSmoothBiSpline |
[frames] | no frames]

# Class HeightSmoothBiSpline

      object --+
               |
    named._Named --+
                   |
        _HeightNamed --+
                       |
             _HeightBase --+
                           |
                          HeightSmoothBiSpline

Height interpolator using `SciPy` SmoothSphereBivariateSpline.

Instance Methods
__init__(self, knots, s=4, **name_wrap) New HeightSmoothBiSpline interpolator. |
__call__(self, *llis, **wrap) Interpolate the height for one or several locations. |
Inherited from `_HeightBase`: `height` Inherited from `_HeightNamed`: `height_` Inherited from `named._Named`: `__format__`, `__imatmul__`, `__matmul__`, `__repr__`, `__rmatmul__`, `__str__`, `attrs`, `classof`, `copy`, `dup`, `methodname`, `rename`, `renamed`, `toRepr`, `toStr`, `toStr2` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Properties
Inherited from `_HeightBase`: `numpy`, `scipy`, `scipy_interpolate` Inherited from `_HeightNamed`: `datum`, `kmin`, `wrap` Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### __init__ (self, knots, s=4, **name_wrap) (Constructor) |
New HeightSmoothBiSpline interpolator. Arguments: `knots` - The points with known height (`LatLon`s). `s` - The spline smoothing factor (`scalar`), default `4`. `name_wrap` - Optional `name=NN` for this height interpolator (`str`) and keyword argument `b{wrap}=False` to wrap or normalize all `knots` and `llis` locations iff `True` (`bool`). Raises: `HeightError` - Insufficient number of `knots` or an invalid `knot` or `s`. `ImportError` - Package `numpy` or `scipy` not found or not installed. `SciPyError` - A `scipy` issue. `SciPyWarning` - A `scipy` warning as exception. Overrides: object.__init__

### __call__ (self, *llis, **wrap) (Call operator) |
Interpolate the height for one or several locations. Arguments: `llis` - One or more locations (each `LatLon`), all positional. `wrap` - If `wrap=True` to wrap or normalize all `llis` locations (`bool`), overriding the `knots`' setting. Returns: A single interpolated height (`float`) or a list or tuple of interpolated heights (each `float`). Raises: `HeightError` - Insufficient number of `llis` or an invalid `lli`. `SciPyError` - A `scipy` issue. `SciPyWarning` - A `scipy` warning as exception. Overrides: _HeightNamed.__call__ See Also: Here for further details.